<?php

/**
 * GavernWP functions and definitions
 *
 * This file contains core framework operations. It is always
 * loaded before the index.php file no the front-end
 *
 * @package WordPress
 * @subpackage GavernWP
 * @since GavernWP 1.0
 **/

if(!function_exists('gavern_file')) {
	/**
	 *
	 * Function used to get the file absolute path - useful when child theme is used
	 *
	 * @return file absolute path (in the original theme or in the child theme if file exists)
	 *
	 **/
	function gavern_file($path) {
		if(is_child_theme()) {
			if($path == false) {
				return get_stylesheet_directory();
			} else {
				if(is_file(get_stylesheet_directory() . DIRECTORY_SEPARATOR . str_replace('/', DIRECTORY_SEPARATOR, $path))) {
					return get_stylesheet_directory() . DIRECTORY_SEPARATOR . str_replace('/', DIRECTORY_SEPARATOR, $path);
				} else {
					return get_template_directory() . DIRECTORY_SEPARATOR . str_replace('/', DIRECTORY_SEPARATOR, $path);
				}
			}
		} else {
			if($path == false) {
				return get_template_directory();
			} else {
				return get_template_directory() . DIRECTORY_SEPARATOR . str_replace('/', DIRECTORY_SEPARATOR, $path);
			}
		}
	}
}

if(!function_exists('gavern_file_uri')) {
	/**
	 *
	 * Function used to get the file URI - useful when child theme is used
	 *
	 * @return file URI (in the original theme or in the child theme if file exists)
	 *
	 **/
	function gavern_file_uri($path) {
		if(is_child_theme()) {
			if($path == false) {
				return get_stylesheet_directory_uri();
			} else {
				if(is_file(get_stylesheet_directory() . DIRECTORY_SEPARATOR . str_replace('/', DIRECTORY_SEPARATOR, $path))) {
					return get_stylesheet_directory_uri() . '/' . $path;
				} else {
					return get_template_directory_uri() . '/' . $path;
				}
			}
		} else {
			if($path == false) {
				return get_template_directory_uri();
			} else {
				return get_template_directory_uri() . '/' . $path;
			}
		}
	}
}
//
if(!class_exists('GavernWP')) {
	// include the framework base class
	require(gavern_file('gavern/base.php'));
}
// load and parse template JSON file.
$config_language = 'en_US';
if(get_locale() != '' && is_dir(get_template_directory() . '/gavern/config/'. get_locale()) && is_dir(get_template_directory() . '/gavern/options/'. get_locale())) {
	$config_language = get_locale();	
}
$json_data = json_decode(file_get_contents(get_template_directory() . '/gavern/config/'.$config_language.'/template.json'));
$tpl_name = strtolower(preg_replace("/[^A-Za-z0-9]/", "", $json_data->template->name));
// define constant to use with all __(), _e(), _n(), _x() and _xe() usage
define('GKTPLNAME', $tpl_name);
// create the framework object
$tpl = new GavernWP();
// Including file with helper functions
require_once(gavern_file('gavern/helpers/helpers.base.php'));
// Including file with template hooks
require_once(gavern_file('gavern/hooks.php'));
// Including file with template functions
require_once(gavern_file('gavern/functions.php'));
require_once(gavern_file('gavern/user.functions.php'));
// Including file with template filters
require_once(gavern_file('gavern/filters.php'));
// Including file with template widgets
require_once(gavern_file('gavern/widgets.comments.php'));
require_once(gavern_file('gavern/widgets.news_gallery.php'));
require_once(gavern_file('gavern/widgets.nsp.php'));
// Including file with template admin features
require_once(gavern_file('gavern/helpers/helpers.features.php'));
// Including file with template shortcodes
require_once(gavern_file('gavern/helpers/helpers.shortcodes.php'));
// Including file with template layout functions
require_once(gavern_file('gavern/helpers/helpers.layout.php'));
// Including file with template layout functions - connected with template fragments
require_once(gavern_file('gavern/helpers/helpers.layout.fragments.php'));
// Including file with template branding functions
require_once(gavern_file('gavern/helpers/helpers.branding.php'));
// Including file with template customize functions
require_once(gavern_file('gavern/helpers/helpers.customizer.php'));
// initialize the framework
$tpl->init();
// add theme setup function
add_action('after_setup_theme', 'gavern_theme_setup');
// Theme setup function
function gavern_theme_setup(){
	// access to the global template object
	global $tpl;
	// variable used for redirects
	global $pagenow;		
	// check if the themes.php address with goto variable has been used
	if ($pagenow == 'themes.php' && !empty($_GET['goto'])) {
		/**
		 *
		 * IMPORTANT FACT: if you're using few different redirects on a lot of subpages
		 * we recommend to define it as themes.php?goto=X, because if you want to
		 * change the URL for X, then you can change it on one place below :)
		 *
		 **/
		
		// check the goto value
		switch ($_GET['goto']) {
			// make proper redirect
			case 'gavick-com':
				wp_redirect("http://www.gavick.com");
				break;
			case 'wiki':
				wp_redirect("http://www.gavick.com/documentation");
				break;
			// or use default redirect
			default:
				wp_safe_redirect('/wp-admin/');
				break;
		}
		exit;
	}
	// if the normal page was requested do following operations:
	
    // load and parse template JSON file.
    $json_data = $tpl->get_json('config','template');
    // read the configuration
    $template_config = $json_data->template;
    // save the lowercase non-special characters template name				
    $template_name = strtolower(preg_replace("/[^A-Za-z0-9]/", "", $template_config->name));
    // load the template text_domain
    load_theme_textdomain( $template_name, get_template_directory() . '/languages' );
}
// scripts enqueue function
function gavern_enqueue_admin_js_and_css() {
	// opengraph scripts
	wp_enqueue_script('gavern.opengraph.js', gavern_file_uri('js/back-end/gavern.opengraph.js'));
	// widget rules JS
	wp_register_script('widget-rules-js', gavern_file_uri('js/back-end/widget.rules.js'), array('jquery'));
	wp_enqueue_script('widget-rules-js');
	// widget rules CSS
	wp_register_style('widget-rules-css', gavern_file_uri('css/back-end/widget.rules.css'));
	wp_enqueue_style('widget-rules-css');
	// GK News Show Pro Widget back-end CSS
	wp_register_style('nsp-admin-css', gavern_file_uri('css/back-end/nsp.css'));
	wp_enqueue_style('nsp-admin-css');
	// shortcodes database
	if(
		get_locale() != '' && 
		is_dir(get_template_directory() . '/gavern/config/'. get_locale()) && 
		is_dir(get_template_directory() . '/gavern/options/'. get_locale())
	) {
		$language = get_locale();	
	} else {
		$language = 'en_US';
	}
	
	wp_enqueue_script('shortcodes.js', gavern_file_uri('gavern/config/'.$language.'/shortcodes.js'));
}
// this action enqueues scripts and styles: 
// http://wpdevel.wordpress.com/2011/12/12/use-wp_enqueue_scripts-not-wp_print_styles-to-enqueue-scripts-and-styles-for-the-frontend/
add_action('admin_enqueue_scripts', 'gavern_enqueue_admin_js_and_css');

// EOF



// 1 - Tie our validation function to the 'gform_validation' hook
add_filter('gform_validation_47', 'validate_vin');
function validate_vin($validation_result) {
    
    // 2 - Get the form object from the validation result
    $form = $validation_result["form"];
    
    // 3 - Get the current page being validated
    $current_page = rgpost('gform_source_page_number_' . $form['id']) ? rgpost('gform_source_page_number_' . $form['id']) : 1;
    
    // 4 - Loop through the form fields
    foreach($form['fields'] as &$field){
        
        // 5 - If the field does not have our designated CSS class, skip it
        if(strpos($field['cssClass'], 'validate-vin') === false)
            continue;
        
        // 6 - Get the field's page number
        $field_page = $field['pageNumber'];
        
        // 7 - Check if the field is hidden by GF conditional logic
        $is_hidden = RGFormsModel::is_field_hidden($form, $field, array());
        
        // 8 - If the field is not on the current page OR if the field is hidden, skip it
        if($field_page != $current_page || $is_hidden)
            continue;
        
        // 9 - Get the submitted value from the $_POST
        $field_value = rgpost("input_{$field['id']}");
        
        // 10 - Make a call to your validation function to validate the value
        $is_valid = is_vin($field_value);
        
        // 11 - If the field is valid we don't need to do anything, skip it
        if($is_valid)
            continue;
        
        // 12 - The field field validation, so first we'll need to fail the validation for the entire form
        $validation_result['is_valid'] = false;
        
        // 13 - Next we'll mark the specific field that failed and add a custom validation message
        $field['failed_validation'] = true;
        $field['validation_message'] = 'The VIN number you have entered is not valid.';
            
    }
    
    // 14 - Assign our modified $form object back to the validation result
    $validation_result['form'] = $form;
    
    // 15 - Return the validation result
    return $validation_result;
}

function is_vin($vin) {
    $vin = strtoupper(trim($vin));
    
    // check VIN length
    if (strlen($vin) != 17) {
        // error VIN is not 17 characters long
        return false;
    }
    
    // setup array of letter values
    $value['A'] = 1;
    $value['B'] = 2;
    $value['C'] = 3;
    $value['D'] = 4;
    $value['E'] = 5;
    $value['F'] = 6;
    $value['G'] = 7;
    $value['H'] = 8;
    $value['J'] = 1;
    $value['K'] = 2;
    $value['L'] = 3;
    $value['M'] = 4;
    $value['N'] = 5;
    $value['P'] = 7;
    $value['R'] = 9;
    $value['S'] = 2;
    $value['T'] = 3;
    $value['U'] = 4;
    $value['V'] = 5;
    $value['W'] = 6;
    $value['X'] = 7;
    $value['Y'] = 8;
    $value['Z'] = 9;
    
    // setup digit weights
    $weight[0] = 8; // 1st position
    $weight[1] = 7;
    $weight[2] = 6;
    $weight[3] = 5;
    $weight[4] = 4;
    $weight[5] = 3;
    $weight[6] = 2;
    $weight[7] = 10;
    $weight[8] = 0; // 9th position, this is the check digit
    $weight[9] = 9;
    $weight[10] = 8;
    $weight[11] = 7;
    $weight[12] = 6;
    $weight[13] = 5;
    $weight[14] = 4;
    $weight[15] = 3;
    $weight[16] = 2; // 17th position
    
    $char = str_split($vin); // split string into character array
    $total = 0;
    
    // loop though each character of the vin
    for ($i = 0; $i < 17; $i++) {
        if (is_numeric($char[$i])) {
            // use number
            // update total
            $total = $total + ($char[$i] * $weight[$i]);
        } elseif (array_key_exists($char[$i], $value)) {
            // use value of letter
            // update total
            $total = $total + ($value[$char[$i]] * $weight[$i]);
        } else {
            // error illegal character used
            return false;
        }
    }
    
    $mod = $total % 11; // find remainder after dividing by 11
    
    // if mod is 10 set the check_digit to X
    if ($mod == 10) {
        $checkDigit = 'X';
    } else {
        $checkDigit = $mod;
    }
    
    // check if the 9th character in the string (the check digit) equals the calculated value
    if ($char[8] == $checkDigit) { 
        // VIN is valid
        return true;
    } else {
        // VIN is not valid
        return false;
    }
}



/* Add a custom field to the field editor (See editor screenshot) */
add_action("gform_field_standard_settings", "my_standard_settings", 10, 2);

function my_standard_settings($position, $form_id){

// Create settings on position 25 (right after Field Label)

if($position == 25){
?>

<li class="admin_label_setting field_setting" style="display: list-item; ">
<label for="field_placeholder">Placeholder Text

<!-- Tooltip to help users understand what this field does -->
<a href="javascript:void(0);" class="tooltip tooltip_form_field_placeholder" tooltip="&lt;h6&gt;Placeholder&lt;/h6&gt;Enter the placeholder/default text for this field.">(?)</a>

</label>

<input type="text" id="field_placeholder" class="fieldwidth-3" size="35" onkeyup="SetFieldProperty('placeholder', this.value);">

</li>
<?php
}
}

/* Now we execute some javascript technicalitites for the field to load correctly */

add_action("gform_editor_js", "my_gform_editor_js");

function my_gform_editor_js(){
?>
<script>
//binding to the load field settings event to initialize the checkbox
jQuery(document).bind("gform_load_field_settings", function(event, field, form){
jQuery("#field_placeholder").val(field["placeholder"]);
});
</script>

<?php
}

/* We use jQuery to read the placeholder value and inject it to its field */

add_action('gform_enqueue_scripts',"my_gform_enqueue_scripts", 10, 2);

function my_gform_enqueue_scripts($form, $is_ajax=false){
?>
<script>

jQuery(function(){
<?php

/* Go through each one of the form fields */

foreach($form['fields'] as $i=>$field){

/* Check if the field has an assigned placeholder */

if(isset($field['placeholder']) && !empty($field['placeholder'])){

/* If a placeholder text exists, inject it as a new property to the field using jQuery */

?>

jQuery('#input_<?php echo $form['id']?>_<?php echo $field['id']?>').attr('placeholder','<?php echo $field['placeholder']?>');

<?php
}
}
?>
});
</script>
<?php
}
